from setuptools import setup, find_packages

setup(
    name='torchaddition',
    version='0.1.0',
    packages=find_packages(),
    install_requires=[
        'torch',
    ],
    author='Your Name',
    description='A simple PyTorch package for additions',
    license='MIT',
)
